__all__ = ["__title__", "__summary__", "__version__", "__author__", "__copyright__"]

__title__ = "gslconsts"
__summary__ = "Python project GNU Scientific Library (GSL) constants"
__version__ = "1.1.2"
__author__ = "Clemson University"
__copyright__ = "Clemson University, 2023"



"""This file was generated automatically.

.. code-block:: python

    # Constants from GSL version 2.7.1 

    GSL_CONST_NUM_FINE_STRUCTURE = 7.297352533e-3
    GSL_CONST_NUM_AVOGADRO = 6.02214199e23
    GSL_CONST_NUM_YOTTA = 1e24
    GSL_CONST_NUM_ZETTA = 1e21
    GSL_CONST_NUM_EXA = 1e18
    GSL_CONST_NUM_PETA = 1e15
    GSL_CONST_NUM_TERA = 1e12
    GSL_CONST_NUM_GIGA = 1e9
    GSL_CONST_NUM_MEGA = 1e6
    GSL_CONST_NUM_KILO = 1e3
    GSL_CONST_NUM_MILLI = 1e-3
    GSL_CONST_NUM_MICRO = 1e-6
    GSL_CONST_NUM_NANO = 1e-9
    GSL_CONST_NUM_PICO = 1e-12
    GSL_CONST_NUM_FEMTO = 1e-15
    GSL_CONST_NUM_ATTO = 1e-18
    GSL_CONST_NUM_ZEPTO = 1e-21
    GSL_CONST_NUM_YOCTO = 1e-24
    GSL_CONST_CGS_SPEED_OF_LIGHT = 2.99792458e10
    GSL_CONST_CGS_GRAVITATIONAL_CONSTANT = 6.673e-8
    GSL_CONST_CGS_PLANCKS_CONSTANT_H = 6.62606896e-27
    GSL_CONST_CGS_PLANCKS_CONSTANT_HBAR = 1.05457162825e-27
    GSL_CONST_CGS_ASTRONOMICAL_UNIT = 1.49597870691e13
    GSL_CONST_CGS_LIGHT_YEAR = 9.46053620707e17
    GSL_CONST_CGS_PARSEC = 3.08567758135e18
    GSL_CONST_CGS_GRAV_ACCEL = 9.80665e2
    GSL_CONST_CGS_ELECTRON_VOLT = 1.602176487e-12
    GSL_CONST_CGS_MASS_ELECTRON = 9.10938188e-28
    GSL_CONST_CGS_MASS_MUON = 1.88353109e-25
    GSL_CONST_CGS_MASS_PROTON = 1.67262158e-24
    GSL_CONST_CGS_MASS_NEUTRON = 1.67492716e-24
    GSL_CONST_CGS_RYDBERG = 2.17987196968e-11
    GSL_CONST_CGS_BOLTZMANN = 1.3806504e-16
    GSL_CONST_CGS_MOLAR_GAS = 8.314472e7
    GSL_CONST_CGS_STANDARD_GAS_VOLUME = 2.2710981e4
    GSL_CONST_CGS_MINUTE = 6e1
    GSL_CONST_CGS_HOUR = 3.6e3
    GSL_CONST_CGS_DAY = 8.64e4
    GSL_CONST_CGS_WEEK = 6.048e5
    GSL_CONST_CGS_INCH = 2.54e0
    GSL_CONST_CGS_FOOT = 3.048e1
    GSL_CONST_CGS_YARD = 9.144e1
    GSL_CONST_CGS_MILE = 1.609344e5
    GSL_CONST_CGS_NAUTICAL_MILE = 1.852e5
    GSL_CONST_CGS_FATHOM = 1.8288e2
    GSL_CONST_CGS_MIL = 2.54e-3
    GSL_CONST_CGS_POINT = 3.52777777778e-2
    GSL_CONST_CGS_TEXPOINT = 3.51459803515e-2
    GSL_CONST_CGS_MICRON = 1e-4
    GSL_CONST_CGS_ANGSTROM = 1e-8
    GSL_CONST_CGS_HECTARE = 1e8
    GSL_CONST_CGS_ACRE = 4.04685642241e7
    GSL_CONST_CGS_BARN = 1e-24
    GSL_CONST_CGS_LITER = 1e3
    GSL_CONST_CGS_US_GALLON = 3.78541178402e3
    GSL_CONST_CGS_QUART = 9.46352946004e2
    GSL_CONST_CGS_PINT = 4.73176473002e2
    GSL_CONST_CGS_CUP = 2.36588236501e2
    GSL_CONST_CGS_FLUID_OUNCE = 2.95735295626e1
    GSL_CONST_CGS_TABLESPOON = 1.47867647813e1
    GSL_CONST_CGS_TEASPOON = 4.92892159375e0
    GSL_CONST_CGS_CANADIAN_GALLON = 4.54609e3
    GSL_CONST_CGS_UK_GALLON = 4.546092e3
    GSL_CONST_CGS_MILES_PER_HOUR = 4.4704e1
    GSL_CONST_CGS_KILOMETERS_PER_HOUR = 2.77777777778e1
    GSL_CONST_CGS_KNOT = 5.14444444444e1
    GSL_CONST_CGS_POUND_MASS = 4.5359237e2
    GSL_CONST_CGS_OUNCE_MASS = 2.8349523125e1
    GSL_CONST_CGS_TON = 9.0718474e5
    GSL_CONST_CGS_METRIC_TON = 1e6
    GSL_CONST_CGS_UK_TON = 1.0160469088e6
    GSL_CONST_CGS_TROY_OUNCE = 3.1103475e1
    GSL_CONST_CGS_CARAT = 2e-1
    GSL_CONST_CGS_UNIFIED_ATOMIC_MASS = 1.660538782e-24
    GSL_CONST_CGS_GRAM_FORCE = 9.80665e2
    GSL_CONST_CGS_POUND_FORCE = 4.44822161526e5
    GSL_CONST_CGS_KILOPOUND_FORCE = 4.44822161526e8
    GSL_CONST_CGS_POUNDAL = 1.38255e4
    GSL_CONST_CGS_CALORIE = 4.1868e7
    GSL_CONST_CGS_BTU = 1.05505585262e10
    GSL_CONST_CGS_THERM = 1.05506e15
    GSL_CONST_CGS_HORSEPOWER = 7.457e9
    GSL_CONST_CGS_BAR = 1e6
    GSL_CONST_CGS_STD_ATMOSPHERE = 1.01325e6
    GSL_CONST_CGS_TORR = 1.33322368421e3
    GSL_CONST_CGS_METER_OF_MERCURY = 1.33322368421e6
    GSL_CONST_CGS_INCH_OF_MERCURY = 3.38638815789e4
    GSL_CONST_CGS_INCH_OF_WATER = 2.490889e3
    GSL_CONST_CGS_PSI = 6.89475729317e4
    GSL_CONST_CGS_POISE = 1e0
    GSL_CONST_CGS_STOKES = 1e0
    GSL_CONST_CGS_STILB = 1e0
    GSL_CONST_CGS_LUMEN = 1e0
    GSL_CONST_CGS_LUX = 1e-4
    GSL_CONST_CGS_PHOT = 1e0
    GSL_CONST_CGS_FOOTCANDLE = 1.076e-3
    GSL_CONST_CGS_LAMBERT = 1e0
    GSL_CONST_CGS_FOOTLAMBERT = 1.07639104e-3
    GSL_CONST_CGS_CURIE = 3.7e10
    GSL_CONST_CGS_ROENTGEN = 2.58e-7
    GSL_CONST_CGS_RAD = 1e2
    GSL_CONST_CGS_SOLAR_MASS = 1.98892e33
    GSL_CONST_CGS_BOHR_RADIUS = 5.291772083e-9
    GSL_CONST_CGS_NEWTON = 1e5
    GSL_CONST_CGS_DYNE = 1e0
    GSL_CONST_CGS_JOULE = 1e7
    GSL_CONST_CGS_ERG = 1e0
    GSL_CONST_CGS_STEFAN_BOLTZMANN_CONSTANT = 5.67040047374e-5
    GSL_CONST_CGS_THOMSON_CROSS_SECTION = 6.65245893699e-25
    GSL_CONST_MKS_SPEED_OF_LIGHT = 2.99792458e8
    GSL_CONST_MKS_GRAVITATIONAL_CONSTANT = 6.673e-11
    GSL_CONST_MKS_PLANCKS_CONSTANT_H = 6.62606896e-34
    GSL_CONST_MKS_PLANCKS_CONSTANT_HBAR = 1.05457162825e-34
    GSL_CONST_MKS_ASTRONOMICAL_UNIT = 1.49597870691e11
    GSL_CONST_MKS_LIGHT_YEAR = 9.46053620707e15
    GSL_CONST_MKS_PARSEC = 3.08567758135e16
    GSL_CONST_MKS_GRAV_ACCEL = 9.80665e0
    GSL_CONST_MKS_ELECTRON_VOLT = 1.602176487e-19
    GSL_CONST_MKS_MASS_ELECTRON = 9.10938188e-31
    GSL_CONST_MKS_MASS_MUON = 1.88353109e-28
    GSL_CONST_MKS_MASS_PROTON = 1.67262158e-27
    GSL_CONST_MKS_MASS_NEUTRON = 1.67492716e-27
    GSL_CONST_MKS_RYDBERG = 2.17987196968e-18
    GSL_CONST_MKS_BOLTZMANN = 1.3806504e-23
    GSL_CONST_MKS_MOLAR_GAS = 8.314472e0
    GSL_CONST_MKS_STANDARD_GAS_VOLUME = 2.2710981e-2
    GSL_CONST_MKS_MINUTE = 6e1
    GSL_CONST_MKS_HOUR = 3.6e3
    GSL_CONST_MKS_DAY = 8.64e4
    GSL_CONST_MKS_WEEK = 6.048e5
    GSL_CONST_MKS_INCH = 2.54e-2
    GSL_CONST_MKS_FOOT = 3.048e-1
    GSL_CONST_MKS_YARD = 9.144e-1
    GSL_CONST_MKS_MILE = 1.609344e3
    GSL_CONST_MKS_NAUTICAL_MILE = 1.852e3
    GSL_CONST_MKS_FATHOM = 1.8288e0
    GSL_CONST_MKS_MIL = 2.54e-5
    GSL_CONST_MKS_POINT = 3.52777777778e-4
    GSL_CONST_MKS_TEXPOINT = 3.51459803515e-4
    GSL_CONST_MKS_MICRON = 1e-6
    GSL_CONST_MKS_ANGSTROM = 1e-10
    GSL_CONST_MKS_HECTARE = 1e4
    GSL_CONST_MKS_ACRE = 4.04685642241e3
    GSL_CONST_MKS_BARN = 1e-28
    GSL_CONST_MKS_LITER = 1e-3
    GSL_CONST_MKS_US_GALLON = 3.78541178402e-3
    GSL_CONST_MKS_QUART = 9.46352946004e-4
    GSL_CONST_MKS_PINT = 4.73176473002e-4
    GSL_CONST_MKS_CUP = 2.36588236501e-4
    GSL_CONST_MKS_FLUID_OUNCE = 2.95735295626e-5
    GSL_CONST_MKS_TABLESPOON = 1.47867647813e-5
    GSL_CONST_MKS_TEASPOON = 4.92892159375e-6
    GSL_CONST_MKS_CANADIAN_GALLON = 4.54609e-3
    GSL_CONST_MKS_UK_GALLON = 4.546092e-3
    GSL_CONST_MKS_MILES_PER_HOUR = 4.4704e-1
    GSL_CONST_MKS_KILOMETERS_PER_HOUR = 2.77777777778e-1
    GSL_CONST_MKS_KNOT = 5.14444444444e-1
    GSL_CONST_MKS_POUND_MASS = 4.5359237e-1
    GSL_CONST_MKS_OUNCE_MASS = 2.8349523125e-2
    GSL_CONST_MKS_TON = 9.0718474e2
    GSL_CONST_MKS_METRIC_TON = 1e3
    GSL_CONST_MKS_UK_TON = 1.0160469088e3
    GSL_CONST_MKS_TROY_OUNCE = 3.1103475e-2
    GSL_CONST_MKS_CARAT = 2e-4
    GSL_CONST_MKS_UNIFIED_ATOMIC_MASS = 1.660538782e-27
    GSL_CONST_MKS_GRAM_FORCE = 9.80665e-3
    GSL_CONST_MKS_POUND_FORCE = 4.44822161526e0
    GSL_CONST_MKS_KILOPOUND_FORCE = 4.44822161526e3
    GSL_CONST_MKS_POUNDAL = 1.38255e-1
    GSL_CONST_MKS_CALORIE = 4.1868e0
    GSL_CONST_MKS_BTU = 1.05505585262e3
    GSL_CONST_MKS_THERM = 1.05506e8
    GSL_CONST_MKS_HORSEPOWER = 7.457e2
    GSL_CONST_MKS_BAR = 1e5
    GSL_CONST_MKS_STD_ATMOSPHERE = 1.01325e5
    GSL_CONST_MKS_TORR = 1.33322368421e2
    GSL_CONST_MKS_METER_OF_MERCURY = 1.33322368421e5
    GSL_CONST_MKS_INCH_OF_MERCURY = 3.38638815789e3
    GSL_CONST_MKS_INCH_OF_WATER = 2.490889e2
    GSL_CONST_MKS_PSI = 6.89475729317e3
    GSL_CONST_MKS_POISE = 1e-1
    GSL_CONST_MKS_STOKES = 1e-4
    GSL_CONST_MKS_STILB = 1e4
    GSL_CONST_MKS_LUMEN = 1e0
    GSL_CONST_MKS_LUX = 1e0
    GSL_CONST_MKS_PHOT = 1e4
    GSL_CONST_MKS_FOOTCANDLE = 1.076e1
    GSL_CONST_MKS_LAMBERT = 1e4
    GSL_CONST_MKS_FOOTLAMBERT = 1.07639104e1
    GSL_CONST_MKS_CURIE = 3.7e10
    GSL_CONST_MKS_ROENTGEN = 2.58e-4
    GSL_CONST_MKS_RAD = 1e-2
    GSL_CONST_MKS_SOLAR_MASS = 1.98892e30
    GSL_CONST_MKS_BOHR_RADIUS = 5.291772083e-11
    GSL_CONST_MKS_NEWTON = 1e0
    GSL_CONST_MKS_DYNE = 1e-5
    GSL_CONST_MKS_JOULE = 1e0
    GSL_CONST_MKS_ERG = 1e-7
    GSL_CONST_MKS_STEFAN_BOLTZMANN_CONSTANT = 5.67040047374e-8
    GSL_CONST_MKS_THOMSON_CROSS_SECTION = 6.65245893699e-29
    GSL_CONST_MKS_BOHR_MAGNETON = 9.27400899e-24
    GSL_CONST_MKS_NUCLEAR_MAGNETON = 5.05078317e-27
    GSL_CONST_MKS_ELECTRON_MAGNETIC_MOMENT = 9.28476362e-24
    GSL_CONST_MKS_PROTON_MAGNETIC_MOMENT = 1.410606633e-26
    GSL_CONST_MKS_FARADAY = 9.64853429775e4
    GSL_CONST_MKS_ELECTRON_CHARGE = 1.602176487e-19
    GSL_CONST_MKS_VACUUM_PERMITTIVITY = 8.854187817e-12
    GSL_CONST_MKS_VACUUM_PERMEABILITY = 1.25663706144e-6
    GSL_CONST_MKS_DEBYE = 3.33564095198e-30
    GSL_CONST_MKS_GAUSS = 1e-4
    GSL_CONST_CGSM_SPEED_OF_LIGHT = 2.99792458e10
    GSL_CONST_CGSM_GRAVITATIONAL_CONSTANT = 6.673e-8
    GSL_CONST_CGSM_PLANCKS_CONSTANT_H = 6.62606896e-27
    GSL_CONST_CGSM_PLANCKS_CONSTANT_HBAR = 1.05457162825e-27
    GSL_CONST_CGSM_ASTRONOMICAL_UNIT = 1.49597870691e13
    GSL_CONST_CGSM_LIGHT_YEAR = 9.46053620707e17
    GSL_CONST_CGSM_PARSEC = 3.08567758135e18
    GSL_CONST_CGSM_GRAV_ACCEL = 9.80665e2
    GSL_CONST_CGSM_ELECTRON_VOLT = 1.602176487e-12
    GSL_CONST_CGSM_MASS_ELECTRON = 9.10938188e-28
    GSL_CONST_CGSM_MASS_MUON = 1.88353109e-25
    GSL_CONST_CGSM_MASS_PROTON = 1.67262158e-24
    GSL_CONST_CGSM_MASS_NEUTRON = 1.67492716e-24
    GSL_CONST_CGSM_RYDBERG = 2.17987196968e-11
    GSL_CONST_CGSM_BOLTZMANN = 1.3806504e-16
    GSL_CONST_CGSM_MOLAR_GAS = 8.314472e7
    GSL_CONST_CGSM_STANDARD_GAS_VOLUME = 2.2710981e4
    GSL_CONST_CGSM_MINUTE = 6e1
    GSL_CONST_CGSM_HOUR = 3.6e3
    GSL_CONST_CGSM_DAY = 8.64e4
    GSL_CONST_CGSM_WEEK = 6.048e5
    GSL_CONST_CGSM_INCH = 2.54e0
    GSL_CONST_CGSM_FOOT = 3.048e1
    GSL_CONST_CGSM_YARD = 9.144e1
    GSL_CONST_CGSM_MILE = 1.609344e5
    GSL_CONST_CGSM_NAUTICAL_MILE = 1.852e5
    GSL_CONST_CGSM_FATHOM = 1.8288e2
    GSL_CONST_CGSM_MIL = 2.54e-3
    GSL_CONST_CGSM_POINT = 3.52777777778e-2
    GSL_CONST_CGSM_TEXPOINT = 3.51459803515e-2
    GSL_CONST_CGSM_MICRON = 1e-4
    GSL_CONST_CGSM_ANGSTROM = 1e-8
    GSL_CONST_CGSM_HECTARE = 1e8
    GSL_CONST_CGSM_ACRE = 4.04685642241e7
    GSL_CONST_CGSM_BARN = 1e-24
    GSL_CONST_CGSM_LITER = 1e3
    GSL_CONST_CGSM_US_GALLON = 3.78541178402e3
    GSL_CONST_CGSM_QUART = 9.46352946004e2
    GSL_CONST_CGSM_PINT = 4.73176473002e2
    GSL_CONST_CGSM_CUP = 2.36588236501e2
    GSL_CONST_CGSM_FLUID_OUNCE = 2.95735295626e1
    GSL_CONST_CGSM_TABLESPOON = 1.47867647813e1
    GSL_CONST_CGSM_TEASPOON = 4.92892159375e0
    GSL_CONST_CGSM_CANADIAN_GALLON = 4.54609e3
    GSL_CONST_CGSM_UK_GALLON = 4.546092e3
    GSL_CONST_CGSM_MILES_PER_HOUR = 4.4704e1
    GSL_CONST_CGSM_KILOMETERS_PER_HOUR = 2.77777777778e1
    GSL_CONST_CGSM_KNOT = 5.14444444444e1
    GSL_CONST_CGSM_POUND_MASS = 4.5359237e2
    GSL_CONST_CGSM_OUNCE_MASS = 2.8349523125e1
    GSL_CONST_CGSM_TON = 9.0718474e5
    GSL_CONST_CGSM_METRIC_TON = 1e6
    GSL_CONST_CGSM_UK_TON = 1.0160469088e6
    GSL_CONST_CGSM_TROY_OUNCE = 3.1103475e1
    GSL_CONST_CGSM_CARAT = 2e-1
    GSL_CONST_CGSM_UNIFIED_ATOMIC_MASS = 1.660538782e-24
    GSL_CONST_CGSM_GRAM_FORCE = 9.80665e2
    GSL_CONST_CGSM_POUND_FORCE = 4.44822161526e5
    GSL_CONST_CGSM_KILOPOUND_FORCE = 4.44822161526e8
    GSL_CONST_CGSM_POUNDAL = 1.38255e4
    GSL_CONST_CGSM_CALORIE = 4.1868e7
    GSL_CONST_CGSM_BTU = 1.05505585262e10
    GSL_CONST_CGSM_THERM = 1.05506e15
    GSL_CONST_CGSM_HORSEPOWER = 7.457e9
    GSL_CONST_CGSM_BAR = 1e6
    GSL_CONST_CGSM_STD_ATMOSPHERE = 1.01325e6
    GSL_CONST_CGSM_TORR = 1.33322368421e3
    GSL_CONST_CGSM_METER_OF_MERCURY = 1.33322368421e6
    GSL_CONST_CGSM_INCH_OF_MERCURY = 3.38638815789e4
    GSL_CONST_CGSM_INCH_OF_WATER = 2.490889e3
    GSL_CONST_CGSM_PSI = 6.89475729317e4
    GSL_CONST_CGSM_POISE = 1e0
    GSL_CONST_CGSM_STOKES = 1e0
    GSL_CONST_CGSM_STILB = 1e0
    GSL_CONST_CGSM_LUMEN = 1e0
    GSL_CONST_CGSM_LUX = 1e-4
    GSL_CONST_CGSM_PHOT = 1e0
    GSL_CONST_CGSM_FOOTCANDLE = 1.076e-3
    GSL_CONST_CGSM_LAMBERT = 1e0
    GSL_CONST_CGSM_FOOTLAMBERT = 1.07639104e-3
    GSL_CONST_CGSM_CURIE = 3.7e10
    GSL_CONST_CGSM_ROENTGEN = 2.58e-8
    GSL_CONST_CGSM_RAD = 1e2
    GSL_CONST_CGSM_SOLAR_MASS = 1.98892e33
    GSL_CONST_CGSM_BOHR_RADIUS = 5.291772083e-9
    GSL_CONST_CGSM_NEWTON = 1e5
    GSL_CONST_CGSM_DYNE = 1e0
    GSL_CONST_CGSM_JOULE = 1e7
    GSL_CONST_CGSM_ERG = 1e0
    GSL_CONST_CGSM_STEFAN_BOLTZMANN_CONSTANT = 5.67040047374e-5
    GSL_CONST_CGSM_THOMSON_CROSS_SECTION = 6.65245893699e-25
    GSL_CONST_CGSM_BOHR_MAGNETON = 9.27400899e-21
    GSL_CONST_CGSM_NUCLEAR_MAGNETON = 5.05078317e-24
    GSL_CONST_CGSM_ELECTRON_MAGNETIC_MOMENT = 9.28476362e-21
    GSL_CONST_CGSM_PROTON_MAGNETIC_MOMENT = 1.410606633e-23
    GSL_CONST_CGSM_FARADAY = 9.64853429775e3
    GSL_CONST_CGSM_ELECTRON_CHARGE = 1.602176487e-20
    GSL_CONST_MKSA_SPEED_OF_LIGHT = 2.99792458e8
    GSL_CONST_MKSA_GRAVITATIONAL_CONSTANT = 6.673e-11
    GSL_CONST_MKSA_PLANCKS_CONSTANT_H = 6.62606896e-34
    GSL_CONST_MKSA_PLANCKS_CONSTANT_HBAR = 1.05457162825e-34
    GSL_CONST_MKSA_ASTRONOMICAL_UNIT = 1.49597870691e11
    GSL_CONST_MKSA_LIGHT_YEAR = 9.46053620707e15
    GSL_CONST_MKSA_PARSEC = 3.08567758135e16
    GSL_CONST_MKSA_GRAV_ACCEL = 9.80665e0
    GSL_CONST_MKSA_ELECTRON_VOLT = 1.602176487e-19
    GSL_CONST_MKSA_MASS_ELECTRON = 9.10938188e-31
    GSL_CONST_MKSA_MASS_MUON = 1.88353109e-28
    GSL_CONST_MKSA_MASS_PROTON = 1.67262158e-27
    GSL_CONST_MKSA_MASS_NEUTRON = 1.67492716e-27
    GSL_CONST_MKSA_RYDBERG = 2.17987196968e-18
    GSL_CONST_MKSA_BOLTZMANN = 1.3806504e-23
    GSL_CONST_MKSA_MOLAR_GAS = 8.314472e0
    GSL_CONST_MKSA_STANDARD_GAS_VOLUME = 2.2710981e-2
    GSL_CONST_MKSA_MINUTE = 6e1
    GSL_CONST_MKSA_HOUR = 3.6e3
    GSL_CONST_MKSA_DAY = 8.64e4
    GSL_CONST_MKSA_WEEK = 6.048e5
    GSL_CONST_MKSA_INCH = 2.54e-2
    GSL_CONST_MKSA_FOOT = 3.048e-1
    GSL_CONST_MKSA_YARD = 9.144e-1
    GSL_CONST_MKSA_MILE = 1.609344e3
    GSL_CONST_MKSA_NAUTICAL_MILE = 1.852e3
    GSL_CONST_MKSA_FATHOM = 1.8288e0
    GSL_CONST_MKSA_MIL = 2.54e-5
    GSL_CONST_MKSA_POINT = 3.52777777778e-4
    GSL_CONST_MKSA_TEXPOINT = 3.51459803515e-4
    GSL_CONST_MKSA_MICRON = 1e-6
    GSL_CONST_MKSA_ANGSTROM = 1e-10
    GSL_CONST_MKSA_HECTARE = 1e4
    GSL_CONST_MKSA_ACRE = 4.04685642241e3
    GSL_CONST_MKSA_BARN = 1e-28
    GSL_CONST_MKSA_LITER = 1e-3
    GSL_CONST_MKSA_US_GALLON = 3.78541178402e-3
    GSL_CONST_MKSA_QUART = 9.46352946004e-4
    GSL_CONST_MKSA_PINT = 4.73176473002e-4
    GSL_CONST_MKSA_CUP = 2.36588236501e-4
    GSL_CONST_MKSA_FLUID_OUNCE = 2.95735295626e-5
    GSL_CONST_MKSA_TABLESPOON = 1.47867647813e-5
    GSL_CONST_MKSA_TEASPOON = 4.92892159375e-6
    GSL_CONST_MKSA_CANADIAN_GALLON = 4.54609e-3
    GSL_CONST_MKSA_UK_GALLON = 4.546092e-3
    GSL_CONST_MKSA_MILES_PER_HOUR = 4.4704e-1
    GSL_CONST_MKSA_KILOMETERS_PER_HOUR = 2.77777777778e-1
    GSL_CONST_MKSA_KNOT = 5.14444444444e-1
    GSL_CONST_MKSA_POUND_MASS = 4.5359237e-1
    GSL_CONST_MKSA_OUNCE_MASS = 2.8349523125e-2
    GSL_CONST_MKSA_TON = 9.0718474e2
    GSL_CONST_MKSA_METRIC_TON = 1e3
    GSL_CONST_MKSA_UK_TON = 1.0160469088e3
    GSL_CONST_MKSA_TROY_OUNCE = 3.1103475e-2
    GSL_CONST_MKSA_CARAT = 2e-4
    GSL_CONST_MKSA_UNIFIED_ATOMIC_MASS = 1.660538782e-27
    GSL_CONST_MKSA_GRAM_FORCE = 9.80665e-3
    GSL_CONST_MKSA_POUND_FORCE = 4.44822161526e0
    GSL_CONST_MKSA_KILOPOUND_FORCE = 4.44822161526e3
    GSL_CONST_MKSA_POUNDAL = 1.38255e-1
    GSL_CONST_MKSA_CALORIE = 4.1868e0
    GSL_CONST_MKSA_BTU = 1.05505585262e3
    GSL_CONST_MKSA_THERM = 1.05506e8
    GSL_CONST_MKSA_HORSEPOWER = 7.457e2
    GSL_CONST_MKSA_BAR = 1e5
    GSL_CONST_MKSA_STD_ATMOSPHERE = 1.01325e5
    GSL_CONST_MKSA_TORR = 1.33322368421e2
    GSL_CONST_MKSA_METER_OF_MERCURY = 1.33322368421e5
    GSL_CONST_MKSA_INCH_OF_MERCURY = 3.38638815789e3
    GSL_CONST_MKSA_INCH_OF_WATER = 2.490889e2
    GSL_CONST_MKSA_PSI = 6.89475729317e3
    GSL_CONST_MKSA_POISE = 1e-1
    GSL_CONST_MKSA_STOKES = 1e-4
    GSL_CONST_MKSA_STILB = 1e4
    GSL_CONST_MKSA_LUMEN = 1e0
    GSL_CONST_MKSA_LUX = 1e0
    GSL_CONST_MKSA_PHOT = 1e4
    GSL_CONST_MKSA_FOOTCANDLE = 1.076e1
    GSL_CONST_MKSA_LAMBERT = 1e4
    GSL_CONST_MKSA_FOOTLAMBERT = 1.07639104e1
    GSL_CONST_MKSA_CURIE = 3.7e10
    GSL_CONST_MKSA_ROENTGEN = 2.58e-4
    GSL_CONST_MKSA_RAD = 1e-2
    GSL_CONST_MKSA_SOLAR_MASS = 1.98892e30
    GSL_CONST_MKSA_BOHR_RADIUS = 5.291772083e-11
    GSL_CONST_MKSA_NEWTON = 1e0
    GSL_CONST_MKSA_DYNE = 1e-5
    GSL_CONST_MKSA_JOULE = 1e0
    GSL_CONST_MKSA_ERG = 1e-7
    GSL_CONST_MKSA_STEFAN_BOLTZMANN_CONSTANT = 5.67040047374e-8
    GSL_CONST_MKSA_THOMSON_CROSS_SECTION = 6.65245893699e-29
    GSL_CONST_MKSA_BOHR_MAGNETON = 9.27400899e-24
    GSL_CONST_MKSA_NUCLEAR_MAGNETON = 5.05078317e-27
    GSL_CONST_MKSA_ELECTRON_MAGNETIC_MOMENT = 9.28476362e-24
    GSL_CONST_MKSA_PROTON_MAGNETIC_MOMENT = 1.410606633e-26
    GSL_CONST_MKSA_FARADAY = 9.64853429775e4
    GSL_CONST_MKSA_ELECTRON_CHARGE = 1.602176487e-19
    GSL_CONST_MKSA_VACUUM_PERMITTIVITY = 8.854187817e-12
    GSL_CONST_MKSA_VACUUM_PERMEABILITY = 1.25663706144e-6
    GSL_CONST_MKSA_DEBYE = 3.33564095198e-30
    GSL_CONST_MKSA_GAUSS = 1e-4
"""

GSL_CONST_NUM_FINE_STRUCTURE = 7.297352533e-3
GSL_CONST_NUM_AVOGADRO = 6.02214199e23
GSL_CONST_NUM_YOTTA = 1e24
GSL_CONST_NUM_ZETTA = 1e21
GSL_CONST_NUM_EXA = 1e18
GSL_CONST_NUM_PETA = 1e15
GSL_CONST_NUM_TERA = 1e12
GSL_CONST_NUM_GIGA = 1e9
GSL_CONST_NUM_MEGA = 1e6
GSL_CONST_NUM_KILO = 1e3
GSL_CONST_NUM_MILLI = 1e-3
GSL_CONST_NUM_MICRO = 1e-6
GSL_CONST_NUM_NANO = 1e-9
GSL_CONST_NUM_PICO = 1e-12
GSL_CONST_NUM_FEMTO = 1e-15
GSL_CONST_NUM_ATTO = 1e-18
GSL_CONST_NUM_ZEPTO = 1e-21
GSL_CONST_NUM_YOCTO = 1e-24
GSL_CONST_CGS_SPEED_OF_LIGHT = 2.99792458e10
GSL_CONST_CGS_GRAVITATIONAL_CONSTANT = 6.673e-8
GSL_CONST_CGS_PLANCKS_CONSTANT_H = 6.62606896e-27
GSL_CONST_CGS_PLANCKS_CONSTANT_HBAR = 1.05457162825e-27
GSL_CONST_CGS_ASTRONOMICAL_UNIT = 1.49597870691e13
GSL_CONST_CGS_LIGHT_YEAR = 9.46053620707e17
GSL_CONST_CGS_PARSEC = 3.08567758135e18
GSL_CONST_CGS_GRAV_ACCEL = 9.80665e2
GSL_CONST_CGS_ELECTRON_VOLT = 1.602176487e-12
GSL_CONST_CGS_MASS_ELECTRON = 9.10938188e-28
GSL_CONST_CGS_MASS_MUON = 1.88353109e-25
GSL_CONST_CGS_MASS_PROTON = 1.67262158e-24
GSL_CONST_CGS_MASS_NEUTRON = 1.67492716e-24
GSL_CONST_CGS_RYDBERG = 2.17987196968e-11
GSL_CONST_CGS_BOLTZMANN = 1.3806504e-16
GSL_CONST_CGS_MOLAR_GAS = 8.314472e7
GSL_CONST_CGS_STANDARD_GAS_VOLUME = 2.2710981e4
GSL_CONST_CGS_MINUTE = 6e1
GSL_CONST_CGS_HOUR = 3.6e3
GSL_CONST_CGS_DAY = 8.64e4
GSL_CONST_CGS_WEEK = 6.048e5
GSL_CONST_CGS_INCH = 2.54e0
GSL_CONST_CGS_FOOT = 3.048e1
GSL_CONST_CGS_YARD = 9.144e1
GSL_CONST_CGS_MILE = 1.609344e5
GSL_CONST_CGS_NAUTICAL_MILE = 1.852e5
GSL_CONST_CGS_FATHOM = 1.8288e2
GSL_CONST_CGS_MIL = 2.54e-3
GSL_CONST_CGS_POINT = 3.52777777778e-2
GSL_CONST_CGS_TEXPOINT = 3.51459803515e-2
GSL_CONST_CGS_MICRON = 1e-4
GSL_CONST_CGS_ANGSTROM = 1e-8
GSL_CONST_CGS_HECTARE = 1e8
GSL_CONST_CGS_ACRE = 4.04685642241e7
GSL_CONST_CGS_BARN = 1e-24
GSL_CONST_CGS_LITER = 1e3
GSL_CONST_CGS_US_GALLON = 3.78541178402e3
GSL_CONST_CGS_QUART = 9.46352946004e2
GSL_CONST_CGS_PINT = 4.73176473002e2
GSL_CONST_CGS_CUP = 2.36588236501e2
GSL_CONST_CGS_FLUID_OUNCE = 2.95735295626e1
GSL_CONST_CGS_TABLESPOON = 1.47867647813e1
GSL_CONST_CGS_TEASPOON = 4.92892159375e0
GSL_CONST_CGS_CANADIAN_GALLON = 4.54609e3
GSL_CONST_CGS_UK_GALLON = 4.546092e3
GSL_CONST_CGS_MILES_PER_HOUR = 4.4704e1
GSL_CONST_CGS_KILOMETERS_PER_HOUR = 2.77777777778e1
GSL_CONST_CGS_KNOT = 5.14444444444e1
GSL_CONST_CGS_POUND_MASS = 4.5359237e2
GSL_CONST_CGS_OUNCE_MASS = 2.8349523125e1
GSL_CONST_CGS_TON = 9.0718474e5
GSL_CONST_CGS_METRIC_TON = 1e6
GSL_CONST_CGS_UK_TON = 1.0160469088e6
GSL_CONST_CGS_TROY_OUNCE = 3.1103475e1
GSL_CONST_CGS_CARAT = 2e-1
GSL_CONST_CGS_UNIFIED_ATOMIC_MASS = 1.660538782e-24
GSL_CONST_CGS_GRAM_FORCE = 9.80665e2
GSL_CONST_CGS_POUND_FORCE = 4.44822161526e5
GSL_CONST_CGS_KILOPOUND_FORCE = 4.44822161526e8
GSL_CONST_CGS_POUNDAL = 1.38255e4
GSL_CONST_CGS_CALORIE = 4.1868e7
GSL_CONST_CGS_BTU = 1.05505585262e10
GSL_CONST_CGS_THERM = 1.05506e15
GSL_CONST_CGS_HORSEPOWER = 7.457e9
GSL_CONST_CGS_BAR = 1e6
GSL_CONST_CGS_STD_ATMOSPHERE = 1.01325e6
GSL_CONST_CGS_TORR = 1.33322368421e3
GSL_CONST_CGS_METER_OF_MERCURY = 1.33322368421e6
GSL_CONST_CGS_INCH_OF_MERCURY = 3.38638815789e4
GSL_CONST_CGS_INCH_OF_WATER = 2.490889e3
GSL_CONST_CGS_PSI = 6.89475729317e4
GSL_CONST_CGS_POISE = 1e0
GSL_CONST_CGS_STOKES = 1e0
GSL_CONST_CGS_STILB = 1e0
GSL_CONST_CGS_LUMEN = 1e0
GSL_CONST_CGS_LUX = 1e-4
GSL_CONST_CGS_PHOT = 1e0
GSL_CONST_CGS_FOOTCANDLE = 1.076e-3
GSL_CONST_CGS_LAMBERT = 1e0
GSL_CONST_CGS_FOOTLAMBERT = 1.07639104e-3
GSL_CONST_CGS_CURIE = 3.7e10
GSL_CONST_CGS_ROENTGEN = 2.58e-7
GSL_CONST_CGS_RAD = 1e2
GSL_CONST_CGS_SOLAR_MASS = 1.98892e33
GSL_CONST_CGS_BOHR_RADIUS = 5.291772083e-9
GSL_CONST_CGS_NEWTON = 1e5
GSL_CONST_CGS_DYNE = 1e0
GSL_CONST_CGS_JOULE = 1e7
GSL_CONST_CGS_ERG = 1e0
GSL_CONST_CGS_STEFAN_BOLTZMANN_CONSTANT = 5.67040047374e-5
GSL_CONST_CGS_THOMSON_CROSS_SECTION = 6.65245893699e-25
GSL_CONST_MKS_SPEED_OF_LIGHT = 2.99792458e8
GSL_CONST_MKS_GRAVITATIONAL_CONSTANT = 6.673e-11
GSL_CONST_MKS_PLANCKS_CONSTANT_H = 6.62606896e-34
GSL_CONST_MKS_PLANCKS_CONSTANT_HBAR = 1.05457162825e-34
GSL_CONST_MKS_ASTRONOMICAL_UNIT = 1.49597870691e11
GSL_CONST_MKS_LIGHT_YEAR = 9.46053620707e15
GSL_CONST_MKS_PARSEC = 3.08567758135e16
GSL_CONST_MKS_GRAV_ACCEL = 9.80665e0
GSL_CONST_MKS_ELECTRON_VOLT = 1.602176487e-19
GSL_CONST_MKS_MASS_ELECTRON = 9.10938188e-31
GSL_CONST_MKS_MASS_MUON = 1.88353109e-28
GSL_CONST_MKS_MASS_PROTON = 1.67262158e-27
GSL_CONST_MKS_MASS_NEUTRON = 1.67492716e-27
GSL_CONST_MKS_RYDBERG = 2.17987196968e-18
GSL_CONST_MKS_BOLTZMANN = 1.3806504e-23
GSL_CONST_MKS_MOLAR_GAS = 8.314472e0
GSL_CONST_MKS_STANDARD_GAS_VOLUME = 2.2710981e-2
GSL_CONST_MKS_MINUTE = 6e1
GSL_CONST_MKS_HOUR = 3.6e3
GSL_CONST_MKS_DAY = 8.64e4
GSL_CONST_MKS_WEEK = 6.048e5
GSL_CONST_MKS_INCH = 2.54e-2
GSL_CONST_MKS_FOOT = 3.048e-1
GSL_CONST_MKS_YARD = 9.144e-1
GSL_CONST_MKS_MILE = 1.609344e3
GSL_CONST_MKS_NAUTICAL_MILE = 1.852e3
GSL_CONST_MKS_FATHOM = 1.8288e0
GSL_CONST_MKS_MIL = 2.54e-5
GSL_CONST_MKS_POINT = 3.52777777778e-4
GSL_CONST_MKS_TEXPOINT = 3.51459803515e-4
GSL_CONST_MKS_MICRON = 1e-6
GSL_CONST_MKS_ANGSTROM = 1e-10
GSL_CONST_MKS_HECTARE = 1e4
GSL_CONST_MKS_ACRE = 4.04685642241e3
GSL_CONST_MKS_BARN = 1e-28
GSL_CONST_MKS_LITER = 1e-3
GSL_CONST_MKS_US_GALLON = 3.78541178402e-3
GSL_CONST_MKS_QUART = 9.46352946004e-4
GSL_CONST_MKS_PINT = 4.73176473002e-4
GSL_CONST_MKS_CUP = 2.36588236501e-4
GSL_CONST_MKS_FLUID_OUNCE = 2.95735295626e-5
GSL_CONST_MKS_TABLESPOON = 1.47867647813e-5
GSL_CONST_MKS_TEASPOON = 4.92892159375e-6
GSL_CONST_MKS_CANADIAN_GALLON = 4.54609e-3
GSL_CONST_MKS_UK_GALLON = 4.546092e-3
GSL_CONST_MKS_MILES_PER_HOUR = 4.4704e-1
GSL_CONST_MKS_KILOMETERS_PER_HOUR = 2.77777777778e-1
GSL_CONST_MKS_KNOT = 5.14444444444e-1
GSL_CONST_MKS_POUND_MASS = 4.5359237e-1
GSL_CONST_MKS_OUNCE_MASS = 2.8349523125e-2
GSL_CONST_MKS_TON = 9.0718474e2
GSL_CONST_MKS_METRIC_TON = 1e3
GSL_CONST_MKS_UK_TON = 1.0160469088e3
GSL_CONST_MKS_TROY_OUNCE = 3.1103475e-2
GSL_CONST_MKS_CARAT = 2e-4
GSL_CONST_MKS_UNIFIED_ATOMIC_MASS = 1.660538782e-27
GSL_CONST_MKS_GRAM_FORCE = 9.80665e-3
GSL_CONST_MKS_POUND_FORCE = 4.44822161526e0
GSL_CONST_MKS_KILOPOUND_FORCE = 4.44822161526e3
GSL_CONST_MKS_POUNDAL = 1.38255e-1
GSL_CONST_MKS_CALORIE = 4.1868e0
GSL_CONST_MKS_BTU = 1.05505585262e3
GSL_CONST_MKS_THERM = 1.05506e8
GSL_CONST_MKS_HORSEPOWER = 7.457e2
GSL_CONST_MKS_BAR = 1e5
GSL_CONST_MKS_STD_ATMOSPHERE = 1.01325e5
GSL_CONST_MKS_TORR = 1.33322368421e2
GSL_CONST_MKS_METER_OF_MERCURY = 1.33322368421e5
GSL_CONST_MKS_INCH_OF_MERCURY = 3.38638815789e3
GSL_CONST_MKS_INCH_OF_WATER = 2.490889e2
GSL_CONST_MKS_PSI = 6.89475729317e3
GSL_CONST_MKS_POISE = 1e-1
GSL_CONST_MKS_STOKES = 1e-4
GSL_CONST_MKS_STILB = 1e4
GSL_CONST_MKS_LUMEN = 1e0
GSL_CONST_MKS_LUX = 1e0
GSL_CONST_MKS_PHOT = 1e4
GSL_CONST_MKS_FOOTCANDLE = 1.076e1
GSL_CONST_MKS_LAMBERT = 1e4
GSL_CONST_MKS_FOOTLAMBERT = 1.07639104e1
GSL_CONST_MKS_CURIE = 3.7e10
GSL_CONST_MKS_ROENTGEN = 2.58e-4
GSL_CONST_MKS_RAD = 1e-2
GSL_CONST_MKS_SOLAR_MASS = 1.98892e30
GSL_CONST_MKS_BOHR_RADIUS = 5.291772083e-11
GSL_CONST_MKS_NEWTON = 1e0
GSL_CONST_MKS_DYNE = 1e-5
GSL_CONST_MKS_JOULE = 1e0
GSL_CONST_MKS_ERG = 1e-7
GSL_CONST_MKS_STEFAN_BOLTZMANN_CONSTANT = 5.67040047374e-8
GSL_CONST_MKS_THOMSON_CROSS_SECTION = 6.65245893699e-29
GSL_CONST_MKS_BOHR_MAGNETON = 9.27400899e-24
GSL_CONST_MKS_NUCLEAR_MAGNETON = 5.05078317e-27
GSL_CONST_MKS_ELECTRON_MAGNETIC_MOMENT = 9.28476362e-24
GSL_CONST_MKS_PROTON_MAGNETIC_MOMENT = 1.410606633e-26
GSL_CONST_MKS_FARADAY = 9.64853429775e4
GSL_CONST_MKS_ELECTRON_CHARGE = 1.602176487e-19
GSL_CONST_MKS_VACUUM_PERMITTIVITY = 8.854187817e-12
GSL_CONST_MKS_VACUUM_PERMEABILITY = 1.25663706144e-6
GSL_CONST_MKS_DEBYE = 3.33564095198e-30
GSL_CONST_MKS_GAUSS = 1e-4
GSL_CONST_CGSM_SPEED_OF_LIGHT = 2.99792458e10
GSL_CONST_CGSM_GRAVITATIONAL_CONSTANT = 6.673e-8
GSL_CONST_CGSM_PLANCKS_CONSTANT_H = 6.62606896e-27
GSL_CONST_CGSM_PLANCKS_CONSTANT_HBAR = 1.05457162825e-27
GSL_CONST_CGSM_ASTRONOMICAL_UNIT = 1.49597870691e13
GSL_CONST_CGSM_LIGHT_YEAR = 9.46053620707e17
GSL_CONST_CGSM_PARSEC = 3.08567758135e18
GSL_CONST_CGSM_GRAV_ACCEL = 9.80665e2
GSL_CONST_CGSM_ELECTRON_VOLT = 1.602176487e-12
GSL_CONST_CGSM_MASS_ELECTRON = 9.10938188e-28
GSL_CONST_CGSM_MASS_MUON = 1.88353109e-25
GSL_CONST_CGSM_MASS_PROTON = 1.67262158e-24
GSL_CONST_CGSM_MASS_NEUTRON = 1.67492716e-24
GSL_CONST_CGSM_RYDBERG = 2.17987196968e-11
GSL_CONST_CGSM_BOLTZMANN = 1.3806504e-16
GSL_CONST_CGSM_MOLAR_GAS = 8.314472e7
GSL_CONST_CGSM_STANDARD_GAS_VOLUME = 2.2710981e4
GSL_CONST_CGSM_MINUTE = 6e1
GSL_CONST_CGSM_HOUR = 3.6e3
GSL_CONST_CGSM_DAY = 8.64e4
GSL_CONST_CGSM_WEEK = 6.048e5
GSL_CONST_CGSM_INCH = 2.54e0
GSL_CONST_CGSM_FOOT = 3.048e1
GSL_CONST_CGSM_YARD = 9.144e1
GSL_CONST_CGSM_MILE = 1.609344e5
GSL_CONST_CGSM_NAUTICAL_MILE = 1.852e5
GSL_CONST_CGSM_FATHOM = 1.8288e2
GSL_CONST_CGSM_MIL = 2.54e-3
GSL_CONST_CGSM_POINT = 3.52777777778e-2
GSL_CONST_CGSM_TEXPOINT = 3.51459803515e-2
GSL_CONST_CGSM_MICRON = 1e-4
GSL_CONST_CGSM_ANGSTROM = 1e-8
GSL_CONST_CGSM_HECTARE = 1e8
GSL_CONST_CGSM_ACRE = 4.04685642241e7
GSL_CONST_CGSM_BARN = 1e-24
GSL_CONST_CGSM_LITER = 1e3
GSL_CONST_CGSM_US_GALLON = 3.78541178402e3
GSL_CONST_CGSM_QUART = 9.46352946004e2
GSL_CONST_CGSM_PINT = 4.73176473002e2
GSL_CONST_CGSM_CUP = 2.36588236501e2
GSL_CONST_CGSM_FLUID_OUNCE = 2.95735295626e1
GSL_CONST_CGSM_TABLESPOON = 1.47867647813e1
GSL_CONST_CGSM_TEASPOON = 4.92892159375e0
GSL_CONST_CGSM_CANADIAN_GALLON = 4.54609e3
GSL_CONST_CGSM_UK_GALLON = 4.546092e3
GSL_CONST_CGSM_MILES_PER_HOUR = 4.4704e1
GSL_CONST_CGSM_KILOMETERS_PER_HOUR = 2.77777777778e1
GSL_CONST_CGSM_KNOT = 5.14444444444e1
GSL_CONST_CGSM_POUND_MASS = 4.5359237e2
GSL_CONST_CGSM_OUNCE_MASS = 2.8349523125e1
GSL_CONST_CGSM_TON = 9.0718474e5
GSL_CONST_CGSM_METRIC_TON = 1e6
GSL_CONST_CGSM_UK_TON = 1.0160469088e6
GSL_CONST_CGSM_TROY_OUNCE = 3.1103475e1
GSL_CONST_CGSM_CARAT = 2e-1
GSL_CONST_CGSM_UNIFIED_ATOMIC_MASS = 1.660538782e-24
GSL_CONST_CGSM_GRAM_FORCE = 9.80665e2
GSL_CONST_CGSM_POUND_FORCE = 4.44822161526e5
GSL_CONST_CGSM_KILOPOUND_FORCE = 4.44822161526e8
GSL_CONST_CGSM_POUNDAL = 1.38255e4
GSL_CONST_CGSM_CALORIE = 4.1868e7
GSL_CONST_CGSM_BTU = 1.05505585262e10
GSL_CONST_CGSM_THERM = 1.05506e15
GSL_CONST_CGSM_HORSEPOWER = 7.457e9
GSL_CONST_CGSM_BAR = 1e6
GSL_CONST_CGSM_STD_ATMOSPHERE = 1.01325e6
GSL_CONST_CGSM_TORR = 1.33322368421e3
GSL_CONST_CGSM_METER_OF_MERCURY = 1.33322368421e6
GSL_CONST_CGSM_INCH_OF_MERCURY = 3.38638815789e4
GSL_CONST_CGSM_INCH_OF_WATER = 2.490889e3
GSL_CONST_CGSM_PSI = 6.89475729317e4
GSL_CONST_CGSM_POISE = 1e0
GSL_CONST_CGSM_STOKES = 1e0
GSL_CONST_CGSM_STILB = 1e0
GSL_CONST_CGSM_LUMEN = 1e0
GSL_CONST_CGSM_LUX = 1e-4
GSL_CONST_CGSM_PHOT = 1e0
GSL_CONST_CGSM_FOOTCANDLE = 1.076e-3
GSL_CONST_CGSM_LAMBERT = 1e0
GSL_CONST_CGSM_FOOTLAMBERT = 1.07639104e-3
GSL_CONST_CGSM_CURIE = 3.7e10
GSL_CONST_CGSM_ROENTGEN = 2.58e-8
GSL_CONST_CGSM_RAD = 1e2
GSL_CONST_CGSM_SOLAR_MASS = 1.98892e33
GSL_CONST_CGSM_BOHR_RADIUS = 5.291772083e-9
GSL_CONST_CGSM_NEWTON = 1e5
GSL_CONST_CGSM_DYNE = 1e0
GSL_CONST_CGSM_JOULE = 1e7
GSL_CONST_CGSM_ERG = 1e0
GSL_CONST_CGSM_STEFAN_BOLTZMANN_CONSTANT = 5.67040047374e-5
GSL_CONST_CGSM_THOMSON_CROSS_SECTION = 6.65245893699e-25
GSL_CONST_CGSM_BOHR_MAGNETON = 9.27400899e-21
GSL_CONST_CGSM_NUCLEAR_MAGNETON = 5.05078317e-24
GSL_CONST_CGSM_ELECTRON_MAGNETIC_MOMENT = 9.28476362e-21
GSL_CONST_CGSM_PROTON_MAGNETIC_MOMENT = 1.410606633e-23
GSL_CONST_CGSM_FARADAY = 9.64853429775e3
GSL_CONST_CGSM_ELECTRON_CHARGE = 1.602176487e-20
GSL_CONST_MKSA_SPEED_OF_LIGHT = 2.99792458e8
GSL_CONST_MKSA_GRAVITATIONAL_CONSTANT = 6.673e-11
GSL_CONST_MKSA_PLANCKS_CONSTANT_H = 6.62606896e-34
GSL_CONST_MKSA_PLANCKS_CONSTANT_HBAR = 1.05457162825e-34
GSL_CONST_MKSA_ASTRONOMICAL_UNIT = 1.49597870691e11
GSL_CONST_MKSA_LIGHT_YEAR = 9.46053620707e15
GSL_CONST_MKSA_PARSEC = 3.08567758135e16
GSL_CONST_MKSA_GRAV_ACCEL = 9.80665e0
GSL_CONST_MKSA_ELECTRON_VOLT = 1.602176487e-19
GSL_CONST_MKSA_MASS_ELECTRON = 9.10938188e-31
GSL_CONST_MKSA_MASS_MUON = 1.88353109e-28
GSL_CONST_MKSA_MASS_PROTON = 1.67262158e-27
GSL_CONST_MKSA_MASS_NEUTRON = 1.67492716e-27
GSL_CONST_MKSA_RYDBERG = 2.17987196968e-18
GSL_CONST_MKSA_BOLTZMANN = 1.3806504e-23
GSL_CONST_MKSA_MOLAR_GAS = 8.314472e0
GSL_CONST_MKSA_STANDARD_GAS_VOLUME = 2.2710981e-2
GSL_CONST_MKSA_MINUTE = 6e1
GSL_CONST_MKSA_HOUR = 3.6e3
GSL_CONST_MKSA_DAY = 8.64e4
GSL_CONST_MKSA_WEEK = 6.048e5
GSL_CONST_MKSA_INCH = 2.54e-2
GSL_CONST_MKSA_FOOT = 3.048e-1
GSL_CONST_MKSA_YARD = 9.144e-1
GSL_CONST_MKSA_MILE = 1.609344e3
GSL_CONST_MKSA_NAUTICAL_MILE = 1.852e3
GSL_CONST_MKSA_FATHOM = 1.8288e0
GSL_CONST_MKSA_MIL = 2.54e-5
GSL_CONST_MKSA_POINT = 3.52777777778e-4
GSL_CONST_MKSA_TEXPOINT = 3.51459803515e-4
GSL_CONST_MKSA_MICRON = 1e-6
GSL_CONST_MKSA_ANGSTROM = 1e-10
GSL_CONST_MKSA_HECTARE = 1e4
GSL_CONST_MKSA_ACRE = 4.04685642241e3
GSL_CONST_MKSA_BARN = 1e-28
GSL_CONST_MKSA_LITER = 1e-3
GSL_CONST_MKSA_US_GALLON = 3.78541178402e-3
GSL_CONST_MKSA_QUART = 9.46352946004e-4
GSL_CONST_MKSA_PINT = 4.73176473002e-4
GSL_CONST_MKSA_CUP = 2.36588236501e-4
GSL_CONST_MKSA_FLUID_OUNCE = 2.95735295626e-5
GSL_CONST_MKSA_TABLESPOON = 1.47867647813e-5
GSL_CONST_MKSA_TEASPOON = 4.92892159375e-6
GSL_CONST_MKSA_CANADIAN_GALLON = 4.54609e-3
GSL_CONST_MKSA_UK_GALLON = 4.546092e-3
GSL_CONST_MKSA_MILES_PER_HOUR = 4.4704e-1
GSL_CONST_MKSA_KILOMETERS_PER_HOUR = 2.77777777778e-1
GSL_CONST_MKSA_KNOT = 5.14444444444e-1
GSL_CONST_MKSA_POUND_MASS = 4.5359237e-1
GSL_CONST_MKSA_OUNCE_MASS = 2.8349523125e-2
GSL_CONST_MKSA_TON = 9.0718474e2
GSL_CONST_MKSA_METRIC_TON = 1e3
GSL_CONST_MKSA_UK_TON = 1.0160469088e3
GSL_CONST_MKSA_TROY_OUNCE = 3.1103475e-2
GSL_CONST_MKSA_CARAT = 2e-4
GSL_CONST_MKSA_UNIFIED_ATOMIC_MASS = 1.660538782e-27
GSL_CONST_MKSA_GRAM_FORCE = 9.80665e-3
GSL_CONST_MKSA_POUND_FORCE = 4.44822161526e0
GSL_CONST_MKSA_KILOPOUND_FORCE = 4.44822161526e3
GSL_CONST_MKSA_POUNDAL = 1.38255e-1
GSL_CONST_MKSA_CALORIE = 4.1868e0
GSL_CONST_MKSA_BTU = 1.05505585262e3
GSL_CONST_MKSA_THERM = 1.05506e8
GSL_CONST_MKSA_HORSEPOWER = 7.457e2
GSL_CONST_MKSA_BAR = 1e5
GSL_CONST_MKSA_STD_ATMOSPHERE = 1.01325e5
GSL_CONST_MKSA_TORR = 1.33322368421e2
GSL_CONST_MKSA_METER_OF_MERCURY = 1.33322368421e5
GSL_CONST_MKSA_INCH_OF_MERCURY = 3.38638815789e3
GSL_CONST_MKSA_INCH_OF_WATER = 2.490889e2
GSL_CONST_MKSA_PSI = 6.89475729317e3
GSL_CONST_MKSA_POISE = 1e-1
GSL_CONST_MKSA_STOKES = 1e-4
GSL_CONST_MKSA_STILB = 1e4
GSL_CONST_MKSA_LUMEN = 1e0
GSL_CONST_MKSA_LUX = 1e0
GSL_CONST_MKSA_PHOT = 1e4
GSL_CONST_MKSA_FOOTCANDLE = 1.076e1
GSL_CONST_MKSA_LAMBERT = 1e4
GSL_CONST_MKSA_FOOTLAMBERT = 1.07639104e1
GSL_CONST_MKSA_CURIE = 3.7e10
GSL_CONST_MKSA_ROENTGEN = 2.58e-4
GSL_CONST_MKSA_RAD = 1e-2
GSL_CONST_MKSA_SOLAR_MASS = 1.98892e30
GSL_CONST_MKSA_BOHR_RADIUS = 5.291772083e-11
GSL_CONST_MKSA_NEWTON = 1e0
GSL_CONST_MKSA_DYNE = 1e-5
GSL_CONST_MKSA_JOULE = 1e0
GSL_CONST_MKSA_ERG = 1e-7
GSL_CONST_MKSA_STEFAN_BOLTZMANN_CONSTANT = 5.67040047374e-8
GSL_CONST_MKSA_THOMSON_CROSS_SECTION = 6.65245893699e-29
GSL_CONST_MKSA_BOHR_MAGNETON = 9.27400899e-24
GSL_CONST_MKSA_NUCLEAR_MAGNETON = 5.05078317e-27
GSL_CONST_MKSA_ELECTRON_MAGNETIC_MOMENT = 9.28476362e-24
GSL_CONST_MKSA_PROTON_MAGNETIC_MOMENT = 1.410606633e-26
GSL_CONST_MKSA_FARADAY = 9.64853429775e4
GSL_CONST_MKSA_ELECTRON_CHARGE = 1.602176487e-19
GSL_CONST_MKSA_VACUUM_PERMITTIVITY = 8.854187817e-12
GSL_CONST_MKSA_VACUUM_PERMEABILITY = 1.25663706144e-6
GSL_CONST_MKSA_DEBYE = 3.33564095198e-30
GSL_CONST_MKSA_GAUSS = 1e-4
